@@ -3,6 +3,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 from cleo.io.null_io import NullIO
+from packaging.utils import NormalizedName
 from packaging.utils import canonicalize_name
 
 from poetry.installation.executor import Executor
@@ -43,6 +44,7 @@ class Installer:
         config: Config,
         installed: Repository | None = None,
         executor: Executor | None = None,
+        disable_cache: bool = False,
     ) -> None:
         self._io = io
         self._env = env
@@ -62,10 +64,12 @@ class Installer:
 
         self._whitelist: list[str] = []
 
-        self._extras: list[str] = []
+        self._extras: list[NormalizedName] = []
 
         if executor is None:
-            executor = Executor(self._env, self._pool, config, self._io)
+            executor = Executor(
+                self._env, self._pool, config, self._io, disable_cache=disable_cache
+            )
 
         self._executor = executor
         self._use_executor = False
@@ -172,7 +176,7 @@ class Installer:
         return self
 
     def extras(self, extras: list[str]) -> Installer:
-        self._extras = extras
+        self._extras = [canonicalize_name(extra) for extra in extras]
 
         return self
 
@@ -215,7 +219,7 @@ class Installer:
 
         locked_repository = Repository("poetry-locked")
         if self._update:
-            if self._locker.is_locked() and not self._lock:
+            if not self._lock and self._locker.is_locked():
                 locked_repository = self._locker.locked_repository()
 
                 # If no packages have been whitelisted (The ones we want to update),
@@ -256,8 +260,12 @@ class Installer:
                     "</warning>"
                 )
 
+            locker_extras = {
+                canonicalize_name(extra)
+                for extra in self._locker.lock_data.get("extras", {})
+            }
             for extra in self._extras:
-                if extra not in self._locker.lock_data.get("extras", {}):
+                if extra not in locker_extras:
                     raise ValueError(f"Extra [{extra}] is not specified.")
 
             # If we are installing from lock
@@ -544,11 +552,17 @@ class Installer:
 
         Maybe we just let the solver handle it?
         """
-        extras: dict[str, list[str]]
+        extras: dict[NormalizedName, list[NormalizedName]]
         if self._update:
             extras = {k: [d.name for d in v] for k, v in self._package.extras.items()}
         else:
-            extras = self._locker.lock_data.get("extras", {})
+            raw_extras = self._locker.lock_data.get("extras", {})
+            extras = {
+                canonicalize_name(extra): [
+                    canonicalize_name(dependency) for dependency in dependencies
+                ]
+                for extra, dependencies in raw_extras.items()
+            }
 
         return list(get_extra_package_names(repo.packages, extras, self._extras))
 
