@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import os
-import re
 import shutil
 import stat
 import sys
@@ -152,18 +151,6 @@ def pluralize(count: int, word: str = "") -> str:
     return word + "s"
 
 
-def safe_extra(extra: str) -> str:
-    """Convert an arbitrary string to a standard 'extra' name.
-
-    Any runs of non-alphanumeric characters are replaced with a single '_',
-    and the result is always lowercased.
-
-    See
-    https://github.com/pypa/setuptools/blob/452e13c/pkg_resources/__init__.py#L1423-L1431.
-    """
-    return re.sub("[^A-Za-z0-9.-]+", "_", extra).lower()
-
-
 def _get_win_folder_from_registry(csidl_name: str) -> str:
     if sys.platform != "win32":
         raise RuntimeError("Method can only be called on Windows.")
